@@ -1,4 +1,6 @@
 package TestComponentForMapFQN;
+use strict;
+use warnings;
 
 sub testcomponentformap_fqn { 'TestComponentForMapFQN works' }
 
